aiomisc - miscellaneous utils for asyncio
=========================================

Miscellaneous utils for asyncio.


How to develop?
---------------

Should be installed:

* `virtualenv`
* GNU Make `make`
* Python 3.5+ `python3.5`


For setting up developer environment just type::

    make develop


